-- ShowResult.e - Shows the output of a call to TaskDialog in TaskDialog.e

include std/console.e
include std/error.e
include std/machine.e

constant codes = {0,"S_OK",
			#800700E,"E_OUTOFMEMORY",
			#80070057,"E_INVALIDARG",
			#80004005,"E_FAIL" }

-- The following constant is intended for diagostic purposes.
constant fields =		-- Fields of TASKDIALOGCONFIG
			{" cbSize"," hwndParent"," hInstance"," dwFlags"," dwCommonButtons",
			" pszWindowTitle"," hMainIcon"," pszMainInstruction"," pszContent",
			" cButtons"," pButtons"," nDefaultButton"," cRadioButtons"," pRadioButtons",
			" nDefaultRadioButton"," pszVerificationText"," pszExpandedInformation",
			" pszExpandedControlText"," pszCollapsedControlText"," hFooterIcon",
			" pszFooter"," pfCallback"," lpCallbackData"," cxWidth"}
constant SizeTD = 4*length(fields)

public procedure ShowRes(object Result)
	atom ptrptr, ptr
	puts(1,"\n\nResult of a call to TaskDialog:\n\n")
	if atom(Result) then
		puts(1,"TASKDIALOGCONFIG address returned. Contents are:\n")
		ptrptr = Result
		for n = 1 to length(fields) do
			printf(1,"At #%08x %s = #%08x\n",{ptrptr,fields[n],peek4u(ptrptr)})
			ptrptr += 4
		end for
		puts(1,"\nThe TASKDIALOGCONFIG is followed by pointers to wstrings\n")
		puts(1,"and other data areas so that they can be freed later\n\nUnicode ")
		puts(1,"characters outside the ASCII range will not display properly\n")
		puts(1,"in a this console window\n\n\n") 
		ptrptr = Result+SizeTD
		while 1 do
			ptr = peek4u(ptrptr)
			if ptr = 0 then
				exit
			else
				-- The button and radio button areas have been 0 terminated
				-- so that peek_wstring doesn't fail here.
				printf(1,"\n#%08x\n%s\n", {ptr,peek_wstring(ptr)} )
				ptrptr += 4
			end if
		end while
		any_key("\nPress a key to display the task dialog\n")
	elsif length(Result) != 4 then
		puts(1,"Invalid return value from TaskDialog\n")
		any_key("Press any key to produce ex.err error report\n")
		crash("Invalid TaskDialog return code")
	else
		printf(1,"Return code =  %s\n",{codes[find(Result[1],codes)+1]} )
		if sequence(Result[2]) then
			printf(1,"Error message:\n%s\nfollowed by\n#%08x\n#%08x\n",Result[2..4] )
		else
			printf(1,"Selected button ID: %d\n",Result[2] )
			printf(1,"Selected radio button ID: %d\n",Result[3] )
			printf(1,"Verification flag = %d\n",Result[4] )
		end if
		any_key("\nPress a key to finish\n")
	end if
end procedure
 
 
21.0